import * as i0 from '@angular/core';
import { Injectable, inject, EventEmitter, Component, Input, Output, NgModule, CUSTOM_ELEMENTS_SCHEMA, Optional, SkipSelf } from '@angular/core';
import createSdk from '@descope/web-js-sdk';
import { from, BehaviorSubject, finalize, tap, of, throwError } from 'rxjs';
import { Router } from '@angular/router';
import { switchMap, catchError } from 'rxjs/operators';
import DescopeWebComponent from '@descope/web-component';
import DescopeUserManagementWidget from '@descope/user-management-widget';
import DescopeRoleManagementWidget from '@descope/role-management-widget';
import DescopeAccessKeyManagementWidget from '@descope/access-key-management-widget';
import DescopeAuditManagementWidget from '@descope/audit-management-widget';
import DescopeUserProfileWidget from '@descope/user-profile-widget';
import DescopeApplicationsPortalWidget from '@descope/applications-portal-widget';

function observabilify(value) {
    /* eslint-disable @typescript-eslint/no-explicit-any */
    const observableValue = {};
    for (const key in value) {
        if (typeof value[key] === 'function') {
            const fn = value[key];
            observableValue[key] = (...args) => {
                const fnResult = fn(...args);
                if (fnResult instanceof Promise) {
                    return from(fnResult);
                }
                else {
                    return fnResult;
                }
            };
        }
        else if (typeof value[key] === 'object' && value[key] !== null) {
            observableValue[key] = observabilify(value[key]);
        }
        else {
            observableValue[key] = value[key];
        }
    }
    return observableValue;
}

const environment = {
    buildVersion: '0.15.18'
};

const baseHeaders = {
    'x-descope-sdk-name': 'angular',
    'x-descope-sdk-version': environment.buildVersion
};
const isBrowser = () => typeof window !== 'undefined';

class DescopeAuthConfig {
    constructor() {
        this.projectId = '';
    }
}

class DescopeAuthService {
    constructor(config) {
        this.descopeSdk = observabilify(createSdk({
            persistTokens: isBrowser(),
            ...config,
            storeLastAuthenticatedUser: isBrowser(),
            autoRefresh: isBrowser(),
            baseHeaders
        }));
        this.sessionSubject = new BehaviorSubject({
            isAuthenticated: false,
            isSessionLoading: false,
            sessionToken: ''
        });
        this.session$ = this.sessionSubject.asObservable();
        this.userSubject = new BehaviorSubject({
            isUserLoading: false
        });
        this.user$ = this.userSubject.asObservable();
        this.descopeSdk.onSessionTokenChange(this.setSession.bind(this));
        this.descopeSdk.onIsAuthenticatedChange(this.setIsAuthenticated.bind(this));
        this.descopeSdk.onUserChange(this.setUser.bind(this));
    }
    refreshSession() {
        const beforeRefreshSession = this.sessionSubject.value;
        this.sessionSubject.next({
            ...beforeRefreshSession,
            isSessionLoading: true
        });
        return this.descopeSdk.refresh().pipe(finalize(() => {
            const afterRefreshSession = this.sessionSubject.value;
            this.sessionSubject.next({
                ...afterRefreshSession,
                isSessionLoading: false
            });
        }));
    }
    refreshUser() {
        const beforeRefreshUser = this.userSubject.value;
        this.userSubject.next({
            ...beforeRefreshUser,
            isUserLoading: true
        });
        return this.descopeSdk.me().pipe(tap((data) => {
            const afterRequestUser = this.userSubject.value;
            if (data.data) {
                this.userSubject.next({
                    ...afterRequestUser,
                    user: {
                        ...data.data
                    }
                });
            }
        }), finalize(() => {
            const afterRefreshUser = this.userSubject.value;
            this.userSubject.next({
                ...afterRefreshUser,
                isUserLoading: false
            });
        }));
    }
    getSessionToken() {
        if (isBrowser()) {
            return this.descopeSdk.getSessionToken();
        }
        console.warn('Get session token is not supported in SSR');
        return '';
    }
    getRefreshToken() {
        if (isBrowser()) {
            return this.descopeSdk.getRefreshToken();
        }
        this.descopeSdk.getJwtPermissions;
        console.warn('Get refresh token is not supported in SSR');
        return '';
    }
    isSessionTokenExpired(token = this.getSessionToken()) {
        if (isBrowser()) {
            return this.descopeSdk.isJwtExpired(token ?? '');
        }
        console.warn('isSessionTokenExpired is not supported in SSR');
        return true;
    }
    isRefreshTokenExpired(token = this.getRefreshToken()) {
        if (isBrowser()) {
            return this.descopeSdk.isJwtExpired(token ?? '');
        }
        console.warn('isRefreshTokenExpired is not supported in SSR');
        return true;
    }
    getJwtPermissions(token = this.getSessionToken(), tenant) {
        if (token === null) {
            console.error('Could not get JWT Permissions - not authenticated');
            return [];
        }
        return this.descopeSdk.getJwtPermissions(token, tenant);
    }
    getJwtRoles(token = this.getSessionToken(), tenant) {
        if (token === null) {
            console.error('Could not get JWT Roles - not authenticated');
            return [];
        }
        return this.descopeSdk.getJwtRoles(token, tenant);
    }
    isAuthenticated() {
        return this.sessionSubject.value.isAuthenticated;
    }
    setSession(sessionToken) {
        const currentSession = this.sessionSubject.value;
        this.sessionSubject.next({
            ...currentSession,
            sessionToken
        });
    }
    setIsAuthenticated(isAuthenticated) {
        const currentSession = this.sessionSubject.value;
        this.sessionSubject.next({
            ...currentSession,
            isAuthenticated
        });
    }
    setUser(user) {
        const currentUser = this.userSubject.value;
        this.userSubject.next({
            isUserLoading: currentUser.isUserLoading,
            user
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthService, deps: [{ token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: DescopeAuthConfig }] });

const descopeAuthGuard = (route) => {
    const authService = inject(DescopeAuthService);
    const router = inject(Router);
    const fallbackUrl = route.data['descopeFallbackUrl'];
    const isAuthenticated = authService.isAuthenticated();
    if (!isAuthenticated && !!fallbackUrl) {
        return from(router.navigate([fallbackUrl]));
    }
    return of(isAuthenticated);
};

const descopeInterceptor = (request, next) => {
    const config = inject(DescopeAuthConfig);
    const authService = inject(DescopeAuthService);
    function refreshAndRetry(request, next, error) {
        return authService.refreshSession().pipe(switchMap((refreshed) => {
            if (refreshed.ok && refreshed.data) {
                const requestWithRefreshedToken = addTokenToRequest(request, refreshed.data?.sessionJwt);
                return next(requestWithRefreshedToken);
            }
            else {
                return throwError(() => error ?? new Error('Could not refresh session!'));
            }
        }));
    }
    function shouldIntercept(request) {
        return ((config.pathsToIntercept?.length === 0 ||
            config.pathsToIntercept?.some((path) => request.url.includes(path))) ??
            true);
    }
    function addTokenToRequest(request, token) {
        return request.clone({
            setHeaders: {
                Authorization: `Bearer ${token}`
            }
        });
    }
    if (shouldIntercept(request)) {
        const token = authService.getSessionToken();
        if (!token) {
            return refreshAndRetry(request, next);
        }
        const requestWithToken = addTokenToRequest(request, token);
        return next(requestWithToken).pipe(catchError((error) => {
            if (error.status === 401 || error.status === 403) {
                return refreshAndRetry(request, next, error);
            }
            else {
                return throwError(() => error);
            }
        }));
    }
    else {
        return next(request);
    }
};

class DescopeComponent {
    constructor(elementRef, authService, descopeConfig) {
        this.elementRef = elementRef;
        this.authService = authService;
        this.success = new EventEmitter();
        this.error = new EventEmitter();
        this.ready = new EventEmitter();
        this.webComponent = new DescopeWebComponent();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
        this.storeLastAuthenticatedUser = descopeConfig.storeLastAuthenticatedUser;
    }
    ngOnInit() {
        const sdk = this.authService.descopeSdk; // Capture the class context in a variable
        const WebComponent = customElements?.get('descope-wc') || DescopeWebComponent;
        WebComponent.sdkConfigOverrides = {
            // Overrides the web-component's base headers to indicate usage via the React SDK
            baseHeaders,
            // Disables token persistence within the web-component to delegate token management
            // to the global SDK hooks. This ensures token handling aligns with the SDK's configuration,
            // and web-component requests leverage the global SDK's beforeRequest hooks for consistency
            persistTokens: false,
            hooks: {
                get beforeRequest() {
                    // Retrieves the beforeRequest hook from the global SDK, which is initialized
                    // within the AuthProvider using the desired configuration. This approach ensures
                    // the web-component utilizes the same beforeRequest hooks as the global SDK
                    return sdk.httpClient.hooks?.beforeRequest;
                },
                set beforeRequest(_) {
                    // The empty setter prevents runtime errors when attempts are made to assign a value to 'beforeRequest'.
                    // JavaScript objects default to having both getters and setters
                }
            }
        };
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('flow-id', this.flowId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.storeLastAuthenticatedUser) {
            this.webComponent.setAttribute('store-last-authenticated-user', this.storeLastAuthenticatedUser.toString());
        }
        if (this.locale) {
            this.webComponent.setAttribute('locale', this.locale);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.tenant) {
            this.webComponent.setAttribute('tenant', this.tenant);
        }
        if (this.telemetryKey) {
            this.webComponent.setAttribute('telemetryKey', this.telemetryKey);
        }
        if (this.redirectUrl) {
            this.webComponent.setAttribute('redirect-url', this.redirectUrl);
        }
        if (this.autoFocus) {
            this.webComponent.setAttribute('auto-focus', this.autoFocus.toString());
        }
        if (this.validateOnBlur) {
            this.webComponent.setAttribute('validate-on-blur', this.validateOnBlur.toString());
        }
        if (this.restartOnError) {
            this.webComponent.setAttribute('restart-on-error', this.restartOnError.toString());
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.styleId) {
            this.webComponent.setAttribute('style-id', this.styleId);
        }
        if (this.errorTransformer) {
            this.webComponent.errorTransformer = this.errorTransformer;
        }
        if (this.onScreenUpdate) {
            this.webComponent.onScreenUpdate = this.onScreenUpdate;
        }
        if (this.client) {
            this.webComponent.setAttribute('client', JSON.stringify(this.client));
        }
        if (this.nonce) {
            this.webComponent.setAttribute('nonce', JSON.stringify(this.nonce));
        }
        if (this.dismissScreenErrorOnInput) {
            this.webComponent.setAttribute('dismiss-screen-error-on-input', JSON.stringify(this.dismissScreenErrorOnInput));
        }
        if (this.form) {
            this.webComponent.setAttribute('form', JSON.stringify(this.form));
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
        this.webComponent.addEventListener('success', (e) => {
            from(this.authService.descopeSdk.httpClient.hooks?.afterRequest(
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            {}, new Response(JSON.stringify(e.detail)))).subscribe(() => {
                if (this.success) {
                    this.success?.emit(e);
                }
            });
        });
        if (this.error) {
            this.webComponent.addEventListener('error', (e) => {
                this.error?.emit(e);
            });
        }
        if (this.ready) {
            this.webComponent.addEventListener('ready', () => {
                this.ready?.emit();
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthService }, { token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: DescopeComponent, isStandalone: true, selector: "descope[flowId]", inputs: { flowId: "flowId", locale: "locale", theme: "theme", tenant: "tenant", telemetryKey: "telemetryKey", redirectUrl: "redirectUrl", autoFocus: "autoFocus", validateOnBlur: "validateOnBlur", restartOnError: "restartOnError", debug: "debug", errorTransformer: "errorTransformer", onScreenUpdate: "onScreenUpdate", client: "client", nonce: "nonce", dismissScreenErrorOnInput: "dismissScreenErrorOnInput", form: "form", logger: "logger", styleId: "styleId" }, outputs: { success: "success", error: "error", ready: "ready" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'descope[flowId]',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthService }, { type: DescopeAuthConfig }], propDecorators: { flowId: [{
                type: Input
            }], locale: [{
                type: Input
            }], theme: [{
                type: Input
            }], tenant: [{
                type: Input
            }], telemetryKey: [{
                type: Input
            }], redirectUrl: [{
                type: Input
            }], autoFocus: [{
                type: Input
            }], validateOnBlur: [{
                type: Input
            }], restartOnError: [{
                type: Input
            }], debug: [{
                type: Input
            }], errorTransformer: [{
                type: Input
            }], onScreenUpdate: [{
                type: Input
            }], client: [{
                type: Input
            }], nonce: [{
                type: Input
            }], dismissScreenErrorOnInput: [{
                type: Input
            }], form: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }], success: [{
                type: Output
            }], error: [{
                type: Output
            }], ready: [{
                type: Output
            }] } });

class SignInFlowComponent {
    constructor(descopeConfig) {
        this.success = new EventEmitter();
        this.error = new EventEmitter();
        this.projectId = descopeConfig.projectId;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: SignInFlowComponent, deps: [{ token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: SignInFlowComponent, isStandalone: true, selector: "descope-sign-in-flow", inputs: { locale: "locale", theme: "theme", tenant: "tenant", telemetryKey: "telemetryKey", redirectUrl: "redirectUrl", autoFocus: "autoFocus", validateOnBlur: "validateOnBlur", restartOnError: "restartOnError", debug: "debug", errorTransformer: "errorTransformer", onScreenUpdate: "onScreenUpdate", client: "client", nonce: "nonce", dismissScreenErrorOnInput: "dismissScreenErrorOnInput", form: "form", logger: "logger", styleId: "styleId" }, outputs: { success: "success", error: "error" }, ngImport: i0, template: "<descope\n  (success)=\"success.emit($event)\"\n  (error)=\"error.emit($event)\"\n  flowId=\"sign-in\"\n  [locale]=\"locale\"\n  [theme]=\"theme\"\n  [tenant]=\"tenant\"\n  [telemetryKey]=\"telemetryKey\"\n  [redirectUrl]=\"redirectUrl\"\n  [autoFocus]=\"autoFocus\"\n  [validateOnBlur]=\"validateOnBlur\"\n  [restartOnError]=\"restartOnError\"\n  [debug]=\"debug\"\n  [errorTransformer]=\"errorTransformer\"\n  [onScreenUpdate]=\"onScreenUpdate\"\n  [client]=\"client\"\n  [nonce]=\"nonce\"\n  [dismissScreenErrorOnInput]=\"dismissScreenErrorOnInput\"\n  [form]=\"form\"\n  [logger]=\"logger\"\n  [styleId]=\"styleId\"\n>\n</descope>\n", dependencies: [{ kind: "component", type: DescopeComponent, selector: "descope[flowId]", inputs: ["flowId", "locale", "theme", "tenant", "telemetryKey", "redirectUrl", "autoFocus", "validateOnBlur", "restartOnError", "debug", "errorTransformer", "onScreenUpdate", "client", "nonce", "dismissScreenErrorOnInput", "form", "logger", "styleId"], outputs: ["success", "error", "ready"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: SignInFlowComponent, decorators: [{
            type: Component,
            args: [{ selector: 'descope-sign-in-flow', standalone: true, imports: [DescopeComponent], template: "<descope\n  (success)=\"success.emit($event)\"\n  (error)=\"error.emit($event)\"\n  flowId=\"sign-in\"\n  [locale]=\"locale\"\n  [theme]=\"theme\"\n  [tenant]=\"tenant\"\n  [telemetryKey]=\"telemetryKey\"\n  [redirectUrl]=\"redirectUrl\"\n  [autoFocus]=\"autoFocus\"\n  [validateOnBlur]=\"validateOnBlur\"\n  [restartOnError]=\"restartOnError\"\n  [debug]=\"debug\"\n  [errorTransformer]=\"errorTransformer\"\n  [onScreenUpdate]=\"onScreenUpdate\"\n  [client]=\"client\"\n  [nonce]=\"nonce\"\n  [dismissScreenErrorOnInput]=\"dismissScreenErrorOnInput\"\n  [form]=\"form\"\n  [logger]=\"logger\"\n  [styleId]=\"styleId\"\n>\n</descope>\n" }]
        }], ctorParameters: () => [{ type: DescopeAuthConfig }], propDecorators: { locale: [{
                type: Input
            }], theme: [{
                type: Input
            }], tenant: [{
                type: Input
            }], telemetryKey: [{
                type: Input
            }], redirectUrl: [{
                type: Input
            }], autoFocus: [{
                type: Input
            }], validateOnBlur: [{
                type: Input
            }], restartOnError: [{
                type: Input
            }], debug: [{
                type: Input
            }], errorTransformer: [{
                type: Input
            }], onScreenUpdate: [{
                type: Input
            }], client: [{
                type: Input
            }], nonce: [{
                type: Input
            }], dismissScreenErrorOnInput: [{
                type: Input
            }], form: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }], success: [{
                type: Output
            }], error: [{
                type: Output
            }] } });

class SignUpFlowComponent {
    constructor(descopeConfig) {
        this.success = new EventEmitter();
        this.error = new EventEmitter();
        this.projectId = descopeConfig.projectId;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: SignUpFlowComponent, deps: [{ token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: SignUpFlowComponent, isStandalone: true, selector: "descope-sign-up-flow", inputs: { locale: "locale", theme: "theme", tenant: "tenant", telemetryKey: "telemetryKey", redirectUrl: "redirectUrl", autoFocus: "autoFocus", validateOnBlur: "validateOnBlur", restartOnError: "restartOnError", debug: "debug", errorTransformer: "errorTransformer", onScreenUpdate: "onScreenUpdate", client: "client", nonce: "nonce", dismissScreenErrorOnInput: "dismissScreenErrorOnInput", form: "form", logger: "logger", styleId: "styleId" }, outputs: { success: "success", error: "error" }, ngImport: i0, template: "<descope\n  (success)=\"success.emit($event)\"\n  (error)=\"error.emit($event)\"\n  flowId=\"sign-up\"\n  [locale]=\"locale\"\n  [theme]=\"theme\"\n  [tenant]=\"tenant\"\n  [telemetryKey]=\"telemetryKey\"\n  [redirectUrl]=\"redirectUrl\"\n  [autoFocus]=\"autoFocus\"\n  [validateOnBlur]=\"validateOnBlur\"\n  [restartOnError]=\"restartOnError\"\n  [debug]=\"debug\"\n  [errorTransformer]=\"errorTransformer\"\n  [onScreenUpdate]=\"onScreenUpdate\"\n  [client]=\"client\"\n  [nonce]=\"nonce\"\n  [dismissScreenErrorOnInput]=\"dismissScreenErrorOnInput\"\n  [form]=\"form\"\n  [logger]=\"logger\"\n  [styleId]=\"styleId\"\n>\n</descope>\n", dependencies: [{ kind: "component", type: DescopeComponent, selector: "descope[flowId]", inputs: ["flowId", "locale", "theme", "tenant", "telemetryKey", "redirectUrl", "autoFocus", "validateOnBlur", "restartOnError", "debug", "errorTransformer", "onScreenUpdate", "client", "nonce", "dismissScreenErrorOnInput", "form", "logger", "styleId"], outputs: ["success", "error", "ready"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: SignUpFlowComponent, decorators: [{
            type: Component,
            args: [{ selector: 'descope-sign-up-flow', standalone: true, imports: [DescopeComponent], template: "<descope\n  (success)=\"success.emit($event)\"\n  (error)=\"error.emit($event)\"\n  flowId=\"sign-up\"\n  [locale]=\"locale\"\n  [theme]=\"theme\"\n  [tenant]=\"tenant\"\n  [telemetryKey]=\"telemetryKey\"\n  [redirectUrl]=\"redirectUrl\"\n  [autoFocus]=\"autoFocus\"\n  [validateOnBlur]=\"validateOnBlur\"\n  [restartOnError]=\"restartOnError\"\n  [debug]=\"debug\"\n  [errorTransformer]=\"errorTransformer\"\n  [onScreenUpdate]=\"onScreenUpdate\"\n  [client]=\"client\"\n  [nonce]=\"nonce\"\n  [dismissScreenErrorOnInput]=\"dismissScreenErrorOnInput\"\n  [form]=\"form\"\n  [logger]=\"logger\"\n  [styleId]=\"styleId\"\n>\n</descope>\n" }]
        }], ctorParameters: () => [{ type: DescopeAuthConfig }], propDecorators: { locale: [{
                type: Input
            }], theme: [{
                type: Input
            }], tenant: [{
                type: Input
            }], telemetryKey: [{
                type: Input
            }], redirectUrl: [{
                type: Input
            }], autoFocus: [{
                type: Input
            }], validateOnBlur: [{
                type: Input
            }], restartOnError: [{
                type: Input
            }], debug: [{
                type: Input
            }], errorTransformer: [{
                type: Input
            }], onScreenUpdate: [{
                type: Input
            }], client: [{
                type: Input
            }], nonce: [{
                type: Input
            }], dismissScreenErrorOnInput: [{
                type: Input
            }], form: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }], success: [{
                type: Output
            }], error: [{
                type: Output
            }] } });

class SignUpOrInFlowComponent {
    constructor(descopeConfig) {
        this.success = new EventEmitter();
        this.error = new EventEmitter();
        this.projectId = descopeConfig.projectId;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: SignUpOrInFlowComponent, deps: [{ token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: SignUpOrInFlowComponent, isStandalone: true, selector: "descope-sign-up-or-in-flow", inputs: { locale: "locale", theme: "theme", tenant: "tenant", telemetryKey: "telemetryKey", redirectUrl: "redirectUrl", autoFocus: "autoFocus", validateOnBlur: "validateOnBlur", restartOnError: "restartOnError", debug: "debug", errorTransformer: "errorTransformer", onScreenUpdate: "onScreenUpdate", client: "client", nonce: "nonce", dismissScreenErrorOnInput: "dismissScreenErrorOnInput", form: "form", logger: "logger", styleId: "styleId" }, outputs: { success: "success", error: "error" }, ngImport: i0, template: "<descope\n  (success)=\"success.emit($event)\"\n  (error)=\"error.emit($event)\"\n  flowId=\"sign-up-or-in\"\n  [locale]=\"locale\"\n  [theme]=\"theme\"\n  [tenant]=\"tenant\"\n  [telemetryKey]=\"telemetryKey\"\n  [redirectUrl]=\"redirectUrl\"\n  [autoFocus]=\"autoFocus\"\n  [validateOnBlur]=\"validateOnBlur\"\n  [restartOnError]=\"restartOnError\"\n  [debug]=\"debug\"\n  [errorTransformer]=\"errorTransformer\"\n  [onScreenUpdate]=\"onScreenUpdate\"\n  [client]=\"client\"\n  [nonce]=\"nonce\"\n  [dismissScreenErrorOnInput]=\"dismissScreenErrorOnInput\"\n  [form]=\"form\"\n  [logger]=\"logger\"\n  [styleId]=\"styleId\"\n>\n</descope>\n", dependencies: [{ kind: "component", type: DescopeComponent, selector: "descope[flowId]", inputs: ["flowId", "locale", "theme", "tenant", "telemetryKey", "redirectUrl", "autoFocus", "validateOnBlur", "restartOnError", "debug", "errorTransformer", "onScreenUpdate", "client", "nonce", "dismissScreenErrorOnInput", "form", "logger", "styleId"], outputs: ["success", "error", "ready"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: SignUpOrInFlowComponent, decorators: [{
            type: Component,
            args: [{ selector: 'descope-sign-up-or-in-flow', standalone: true, imports: [DescopeComponent], template: "<descope\n  (success)=\"success.emit($event)\"\n  (error)=\"error.emit($event)\"\n  flowId=\"sign-up-or-in\"\n  [locale]=\"locale\"\n  [theme]=\"theme\"\n  [tenant]=\"tenant\"\n  [telemetryKey]=\"telemetryKey\"\n  [redirectUrl]=\"redirectUrl\"\n  [autoFocus]=\"autoFocus\"\n  [validateOnBlur]=\"validateOnBlur\"\n  [restartOnError]=\"restartOnError\"\n  [debug]=\"debug\"\n  [errorTransformer]=\"errorTransformer\"\n  [onScreenUpdate]=\"onScreenUpdate\"\n  [client]=\"client\"\n  [nonce]=\"nonce\"\n  [dismissScreenErrorOnInput]=\"dismissScreenErrorOnInput\"\n  [form]=\"form\"\n  [logger]=\"logger\"\n  [styleId]=\"styleId\"\n>\n</descope>\n" }]
        }], ctorParameters: () => [{ type: DescopeAuthConfig }], propDecorators: { locale: [{
                type: Input
            }], theme: [{
                type: Input
            }], tenant: [{
                type: Input
            }], telemetryKey: [{
                type: Input
            }], redirectUrl: [{
                type: Input
            }], autoFocus: [{
                type: Input
            }], validateOnBlur: [{
                type: Input
            }], restartOnError: [{
                type: Input
            }], debug: [{
                type: Input
            }], errorTransformer: [{
                type: Input
            }], onScreenUpdate: [{
                type: Input
            }], client: [{
                type: Input
            }], nonce: [{
                type: Input
            }], dismissScreenErrorOnInput: [{
                type: Input
            }], form: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }], success: [{
                type: Output
            }], error: [{
                type: Output
            }] } });

class UserManagementComponent {
    constructor(elementRef, descopeConfig) {
        this.elementRef = elementRef;
        this.webComponent = new DescopeUserManagementWidget();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
    }
    ngOnInit() {
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('tenant', this.tenant);
        this.webComponent.setAttribute('widget-id', this.widgetId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.styleId) {
            this.webComponent.setAttribute('style-id', this.styleId);
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: UserManagementComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: UserManagementComponent, isStandalone: true, selector: "user-management[tenant]", inputs: { tenant: "tenant", widgetId: "widgetId", theme: "theme", debug: "debug", logger: "logger", styleId: "styleId" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: UserManagementComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'user-management[tenant]',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthConfig }], propDecorators: { tenant: [{
                type: Input
            }], widgetId: [{
                type: Input
            }], theme: [{
                type: Input
            }], debug: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }] } });

class RoleManagementComponent {
    constructor(elementRef, descopeConfig) {
        this.elementRef = elementRef;
        this.webComponent = new DescopeRoleManagementWidget();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
    }
    ngOnInit() {
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('tenant', this.tenant);
        this.webComponent.setAttribute('widget-id', this.widgetId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.styleId) {
            this.webComponent.setAttribute('style-id', this.styleId);
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: RoleManagementComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: RoleManagementComponent, isStandalone: true, selector: "role-management[tenant]", inputs: { tenant: "tenant", widgetId: "widgetId", theme: "theme", debug: "debug", logger: "logger", styleId: "styleId" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: RoleManagementComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'role-management[tenant]',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthConfig }], propDecorators: { tenant: [{
                type: Input
            }], widgetId: [{
                type: Input
            }], theme: [{
                type: Input
            }], debug: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }] } });

class AccessKeyManagementComponent {
    constructor(elementRef, descopeConfig) {
        this.elementRef = elementRef;
        this.webComponent = new DescopeAccessKeyManagementWidget();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
    }
    ngOnInit() {
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('tenant', this.tenant);
        this.webComponent.setAttribute('widget-id', this.widgetId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: AccessKeyManagementComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: AccessKeyManagementComponent, isStandalone: true, selector: "access-key-management[tenant]", inputs: { tenant: "tenant", widgetId: "widgetId", theme: "theme", debug: "debug", logger: "logger", styleId: "styleId" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: AccessKeyManagementComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'access-key-management[tenant]',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthConfig }], propDecorators: { tenant: [{
                type: Input
            }], widgetId: [{
                type: Input
            }], theme: [{
                type: Input
            }], debug: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }] } });

class AuditManagementComponent {
    constructor(elementRef, descopeConfig) {
        this.elementRef = elementRef;
        this.webComponent = new DescopeAuditManagementWidget();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
    }
    ngOnInit() {
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('tenant', this.tenant);
        this.webComponent.setAttribute('widget-id', this.widgetId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.styleId) {
            this.webComponent.setAttribute('style-id', this.styleId);
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: AuditManagementComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: AuditManagementComponent, isStandalone: true, selector: "audit-management[tenant]", inputs: { tenant: "tenant", widgetId: "widgetId", theme: "theme", debug: "debug", logger: "logger", styleId: "styleId" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: AuditManagementComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'audit-management[tenant]',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthConfig }], propDecorators: { tenant: [{
                type: Input
            }], widgetId: [{
                type: Input
            }], theme: [{
                type: Input
            }], debug: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }] } });

class UserProfileComponent {
    constructor(elementRef, descopeConfig, descopeAuthService) {
        this.elementRef = elementRef;
        this.descopeAuthService = descopeAuthService;
        this.logout = new EventEmitter();
        this.webComponent = new DescopeUserProfileWidget();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
    }
    ngOnInit() {
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('widget-id', this.widgetId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.styleId) {
            this.webComponent.setAttribute('style-id', this.styleId);
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
        this.webComponent.addEventListener('logout', (e) => {
            this.logout?.emit(e);
            this.descopeAuthService.setSession('');
            this.descopeAuthService.setIsAuthenticated(false);
            this.descopeAuthService.setUser(null);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: UserProfileComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthConfig }, { token: DescopeAuthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: UserProfileComponent, isStandalone: true, selector: "user-profile", inputs: { widgetId: "widgetId", theme: "theme", debug: "debug", logger: "logger", styleId: "styleId" }, outputs: { logout: "logout" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: UserProfileComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'user-profile',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthConfig }, { type: DescopeAuthService }], propDecorators: { widgetId: [{
                type: Input
            }], theme: [{
                type: Input
            }], debug: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }], logout: [{
                type: Output
            }] } });

class ApplicationsPortalComponent {
    constructor(elementRef, descopeConfig) {
        this.elementRef = elementRef;
        this.logout = new EventEmitter();
        this.webComponent = new DescopeApplicationsPortalWidget();
        this.projectId = descopeConfig.projectId;
        this.baseUrl = descopeConfig.baseUrl;
        this.baseStaticUrl = descopeConfig.baseStaticUrl;
        this.baseCdnUrl = descopeConfig.baseCdnUrl;
    }
    ngOnInit() {
        this.setupWebComponent();
        this.elementRef.nativeElement.appendChild(this.webComponent);
    }
    ngOnChanges() {
        this.setupWebComponent();
    }
    setupWebComponent() {
        this.webComponent.setAttribute('project-id', this.projectId);
        this.webComponent.setAttribute('widget-id', this.widgetId);
        if (this.baseUrl) {
            this.webComponent.setAttribute('base-url', this.baseUrl);
        }
        if (this.baseStaticUrl) {
            this.webComponent.setAttribute('base-static-url', this.baseStaticUrl);
        }
        if (this.baseCdnUrl) {
            this.webComponent.setAttribute('base-cdn-url', this.baseCdnUrl);
        }
        if (this.theme) {
            this.webComponent.setAttribute('theme', this.theme);
        }
        if (this.debug) {
            this.webComponent.setAttribute('debug', this.debug.toString());
        }
        if (this.logger) {
            this.webComponent.logger = this.logger;
        }
        if (this.styleId) {
            this.webComponent.setAttribute('style-id', this.styleId);
        }
        if (this.logout) {
            this.webComponent.addEventListener('logout', (e) => {
                this.logout?.emit(e);
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: ApplicationsPortalComponent, deps: [{ token: i0.ElementRef }, { token: DescopeAuthConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.1.4", type: ApplicationsPortalComponent, isStandalone: true, selector: "applications-portal", inputs: { widgetId: "widgetId", theme: "theme", debug: "debug", logger: "logger", styleId: "styleId" }, outputs: { logout: "logout" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: ApplicationsPortalComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'applications-portal',
                    standalone: true,
                    template: ''
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DescopeAuthConfig }], propDecorators: { widgetId: [{
                type: Input
            }], theme: [{
                type: Input
            }], debug: [{
                type: Input
            }], logger: [{
                type: Input
            }], styleId: [{
                type: Input
            }], logout: [{
                type: Output
            }] } });

class DescopeAuthModule {
    constructor(parentModule) {
        if (parentModule) {
            // eslint-disable-next-line no-console
            console.log('DescopeAuthModule is loaded in a child module');
        }
    }
    static forRoot(config) {
        return {
            ngModule: DescopeAuthModule,
            providers: [{ provide: DescopeAuthConfig, useValue: config }]
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthModule, deps: [{ token: DescopeAuthModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthModule, imports: [DescopeComponent,
            SignInFlowComponent,
            SignUpFlowComponent,
            SignUpOrInFlowComponent,
            UserManagementComponent,
            RoleManagementComponent,
            AccessKeyManagementComponent,
            AuditManagementComponent,
            UserProfileComponent,
            ApplicationsPortalComponent], exports: [DescopeComponent,
            SignInFlowComponent,
            SignUpFlowComponent,
            SignUpOrInFlowComponent,
            UserManagementComponent,
            RoleManagementComponent,
            AccessKeyManagementComponent,
            AuditManagementComponent,
            UserProfileComponent,
            ApplicationsPortalComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: DescopeAuthModule, decorators: [{
            type: NgModule,
            args: [{
                    schemas: [CUSTOM_ELEMENTS_SCHEMA],
                    imports: [
                        DescopeComponent,
                        SignInFlowComponent,
                        SignUpFlowComponent,
                        SignUpOrInFlowComponent,
                        UserManagementComponent,
                        RoleManagementComponent,
                        AccessKeyManagementComponent,
                        AuditManagementComponent,
                        UserProfileComponent,
                        ApplicationsPortalComponent
                    ],
                    exports: [
                        DescopeComponent,
                        SignInFlowComponent,
                        SignUpFlowComponent,
                        SignUpOrInFlowComponent,
                        UserManagementComponent,
                        RoleManagementComponent,
                        AccessKeyManagementComponent,
                        AuditManagementComponent,
                        UserProfileComponent,
                        ApplicationsPortalComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: DescopeAuthModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/*
 * Public API Surface of angular-sdk
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AccessKeyManagementComponent, ApplicationsPortalComponent, AuditManagementComponent, DescopeAuthConfig, DescopeAuthModule, DescopeAuthService, DescopeComponent, RoleManagementComponent, SignInFlowComponent, SignUpFlowComponent, SignUpOrInFlowComponent, UserManagementComponent, UserProfileComponent, descopeAuthGuard, descopeInterceptor };
//# sourceMappingURL=descope-angular-sdk.mjs.map
